create table "customers" (
	"cust_id" integer not null default nextval('id'::text) primary key,
	"name" character varying(40) not null default '',
	"sname" character varying(40) not null default '',
	"phone" character varying(40) not null default '',
	"icq" character varying(24) not null default '',
	"email" character varying(64) not null default '',
	"address" character varying(128) not null default '',
	"comments" character varying(300) not null default ''
);

create table "tariffs_names" (
	"tariff_id" integer not null default nextval('id'::text) primary key,
	"name" character varying(128)
);

create table "logins" (
	"cust_id" integer NOT NULL,
	"login_id" integer NOT NULL PRIMARY KEY default nextval('id'::text),
	"tariff_id" integer not null default 0,
	"login" character varying(16) NOT NULL UNIQUE,
	"paused" boolean default 'f',
	"detailed" boolean default 'f',
	"ip_addr" character varying(48) not null default 0,
	"fixed_ip" character varying(48) not null default 0,
	"email" integer default 0,
	"hosting" integer default 0,
	"vpn" integer default 0,
	"dialup" integer default 0,
	"ftp" integer default 0,
	"shell" integer default 0,
	    FOREIGN KEY ("cust_id") references "customers" ON DELETE cascade ON UPDATE cascade,
	    foreign key ("tariff_id") references "tariffs_names" on delete set default on update cascade
);

CREATE TABLE "cash" (
        "cust_id" integer NOT NULL,
        "cash" double precision DEFAULT 0,
        "kredit" double precision DEFAULT 0,
	    foreign key ("cust_id") references "customers" on delete cascade on update cascade
);

create table "pwds_names" (
	"pwd_id" integer not null default nextval('id'::text) primary key,
	"name" character varying(32) NOT NULL,
	"crypt" character varying(16) NOT NULL default 'crypt'
);

create table "pwds" (
	"pwd_id" integer not null,
	"login_id" integer not null,
	"pwd" character varying(32) not null,
	    foreign key ("pwd_id") references "pwds_names" ON DELETE cascade ON UPDATE cascade,
	    FOREIGN KEY ("login_id") references "logins" ON DELETE cascade ON UPDATE cascade
);

create table "logs_time" (
	"login_id" integer NOT NULL,
	"login" integer NOT NULL default 0,
	"logoff" integer NOT NULL default 0,
	    FOREIGN KEY ("login_id") references "logins"  ON DELETE cascade ON UPDATE cascade
);

create table "nets_names" (
	"net_id" integer not null default nextval('id'::text) primary key,
	"name" character varying(128)
);

create table "nets" (
	"net_id" integer not null,
	"cidr" character varying(64),
	    foreign key ("net_id") references "nets_names" on delete cascade on update cascade
);

create table "services_names" (
	"service_id" integer not null default nextval('id'::text) primary key,
	"name" character varying(128)
);

create table "services" (
        "service_id" integer not null,
        "dest" character varying(24),
        "proto" character varying(16),
        "net_id" integer,
        "agent" character varying(24),
        "sport" character varying(24),
        "dport" character varying(24),
        "iface" character varying(24),
	    foreign key ("service_id") references  "services_names" on delete cascade on update cascade
);

create table "logs_ng" (
	"login_id" integer NOT NULL,
	"service_id" integer NOT NULL,
	"bytes" bigint DEFAULT 0 NOT NULL,
	"pkts" bigint DEFAULT 0  NOT NULL,
	"timestamp" bigint NOT NULL, 
	    FOREIGN KEY ("login_id") references "logins" ON DELETE cascade ON UPDATE cascade,
	    FOREIGN KEY ("service_id") references "services_names" ON DELETE cascade ON UPDATE cascade
);

create index "logs_ng_time" on "logs_ng" ("timestamp");
create index "logs_ng_login_time" on "logs_ng" ("login_id", "timestamp");

create table "logs_raw" (
	"source" character varying(24),
	"destination" character varying(24),
	"proto" character varying(16),
	"sport" character varying(16),
	"dport" character varying(16),
	"timestamp" bigint not null,
	"len" integer
);

create index "logs_raw_time" on "logs_raw" ("timestamp");

create table "tariffs" (
	"tariff_id" integer not null,
	"pay_type" integer not null,
	"length" character varying(32) not null,
	"s_volume" bigint not null default 0,
	"e_volume" bigint not null default 9999999999,
	"price" bigint not null,
	"service_id" integer not null,
	    foreign key ("tariff_id") references "tariffs_names" on delete cascade on update cascade,
	    foreign key ("service_id") references "services_names" on delete cascade on update cascade
);

create table "periods" (
	"login_id" integer not null,
	"p_start" bigint not null,
	"p_end" bigint not null,
	"volume" bigint not null,
	"paid" bigint not null,
	    foreign key ("login_id") references "logins" on delete cascade on update cascade
);

create table "periods_old" (
	"login_id" integer not null,
	"p_start" bigint not null,
	"p_end" bigint not null,
	"volume" bigint not null,
	"paid" bigint not null,
	    foreign key ("login_id") references "logins" on delete cascade on update cascade
);

create table "billed" (
	"billed_on" bigint not null default 0
);
